@@ -34,6 +34,18 @@ option add *menubar.windowbutton*background beige
 option add *menubar.netlistbutton*background beige
 option add *menubar*font -*-times-bold-r-normal--14-*
 
+option add *librarymenu*activeBackground brown4
+option add *librarymenu*foreground brown4
+option add *librarymenu*activeForeground beige
+option add *librarymenu*font -*-times-bold-r-normal--14-*
+option add *librarymenu*background beige
+
+option add *pagemenu*activeBackground brown4
+option add *pagemenu*foreground brown4
+option add *pagemenu*activeForeground beige
+option add *pagemenu*font -*-times-bold-r-normal--14-*
+option add *pagemenu*background beige
+
 option add *filelist*activeBackground brown4
 option add *filelist*foreground brown4
 option add *filelist*activeForeground beige
