@@ -269,7 +269,9 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       deselect
       pop
    } else {
+      library $XCOps(library) compose
       deselect
+      symbol goto
       zoom view
    }
 }
