@@ -257,7 +257,8 @@ extern void loadblib();
 extern void getlib(xcWidget, caddr_t, caddr_t);
 extern void getuserlib(xcWidget, caddr_t, caddr_t);
 extern Boolean loadlibrary(short);
-extern void startloadfile();
+extern void startloadfile(int);
+extern void normalloadfile();
 extern void importfile();
 extern Boolean loadfile(short, int);
 extern void readlabel(objectptr, char *, stringpart **);
@@ -438,6 +439,7 @@ extern short *pagetotals(int, short);
 extern Boolean is_virtual(objinstptr);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
+extern int name_to_library(char *);
 extern int libfindobject(objectptr, int *);
 extern int libmoveobject(objectptr, int);
 extern void pagecat_op(int, int, int);
