@@ -921,7 +921,7 @@ static PyObject *xc_load(PyObject *self, PyObject *args)
 
    strcpy(_STR2, filename);
    if (savepage != pageno) newpage(pageno);
-   startloadfile();
+   startloadfile(-1);
    if (savepage != pageno) newpage(savepage);
 
    return PyString_FromString(filename);
