@@ -309,7 +309,8 @@ enum editmode {
   EARC_MODE,		/* Editing an existing arc */
   ESPLINE_MODE,		/* Editing an existing spline */
   EPATH_MODE,		/* Editing an existing path */
-  ASSOC_MODE		/* Choosing an associated schematic or symbol */
+  ASSOC_MODE,		/* Choosing an associated schematic or symbol */
+  CATMOVE_MODE		/* Moving objects in or between libraries */
 };
 
 /*----------------------------------------------------------------------*/
@@ -1364,11 +1365,17 @@ typedef struct _undostack {
 
 typedef struct {
    char		*filename;	/* Last file loaded into the library */
+   char		flags;		/* Flags for library page (changed, read-only) */
    short	number;
    objectptr	*library;
    liblistptr	instlist;	/* List of instances */
 } Library;
 
+/* Known flags for library pages */
+
+#define LIBRARY_CHANGED		0x01
+#define LIBRARY_READONLY	0x02
+
 /*----------------------------------------------------------------------*/
 /* A convenient structure for holding all the object lists		*/
 /*----------------------------------------------------------------------*/
@@ -1383,6 +1390,7 @@ typedef struct {
    int		save_interval;
    short	do_replace;
    Boolean	filefilter;	/* Is the file list filtered? */
+   Boolean	hold;		/* allow HOLD modifiers on buttons */
    u_short	new_changes;
    short	numlibs;
    short	pages;
